summaryrefslogtreecommitdiff
path: root/uvim/runtime/tools
diff options
context:
space:
mode:
authorMehmet Samet Duman <yongdohyun@projecttick.org>2026-04-03 22:21:25 +0300
committerMehmet Samet Duman <yongdohyun@projecttick.org>2026-04-04 00:23:03 +0300
commit2eae5db069dc171f74cd863487655f6a88e5384d (patch)
tree2d9d05e09978a2a44acbfbb8d651f240df3ca052 /uvim/runtime/tools
parent473d922faed49241a5d29d9e37dc4819cd512006 (diff)
downloadProject-Tick-2eae5db069dc171f74cd863487655f6a88e5384d.tar.gz
Project-Tick-2eae5db069dc171f74cd863487655f6a88e5384d.zip
NOISSUE rebrand vim to MNV's not Vim
Signed-off-by: Mehmet Samet Duman <yongdohyun@projecttick.org>
Diffstat (limited to 'uvim/runtime/tools')
-rw-r--r--uvim/runtime/tools/README.txt20
-rw-r--r--uvim/runtime/tools/ccfilter.110
-rw-r--r--uvim/runtime/tools/ccfilter.c4
-rw-r--r--uvim/runtime/tools/ccfilter_README.txt2
-rw-r--r--uvim/runtime/tools/demoserver.py10
-rwxr-xr-xuvim/runtime/tools/efm_filter.pl4
-rw-r--r--uvim/runtime/tools/efm_filter.txt8
-rwxr-xr-xuvim/runtime/tools/efm_perl.pl30
-rw-r--r--uvim/runtime/tools/emoji_list.mnv (renamed from uvim/runtime/tools/emoji_list.vim)2
-rwxr-xr-xuvim/runtime/tools/mnv132 (renamed from uvim/runtime/tools/vim132)4
-rw-r--r--uvim/runtime/tools/mnv_vs_net.cmd (renamed from uvim/runtime/tools/vim_vs_net.cmd)14
-rwxr-xr-xuvim/runtime/tools/mnvm (renamed from uvim/runtime/tools/vimm)2
-rwxr-xr-xuvim/runtime/tools/mnvspell.sh (renamed from uvim/runtime/tools/vimspell.sh)16
-rw-r--r--uvim/runtime/tools/mnvspell.txt (renamed from uvim/runtime/tools/vimspell.txt)8
-rwxr-xr-xuvim/runtime/tools/mve.awk4
-rw-r--r--uvim/runtime/tools/mve.txt6
-rwxr-xr-xuvim/runtime/tools/pltags.pl8
-rw-r--r--uvim/runtime/tools/preproc_indent.mnv (renamed from uvim/runtime/tools/preproc_indent.vim)8
-rwxr-xr-xuvim/runtime/tools/ref2
-rw-r--r--uvim/runtime/tools/unicode.mnv (renamed from uvim/runtime/tools/unicode.vim)2
-rw-r--r--uvim/runtime/tools/xcmdsrv_client.c24
21 files changed, 94 insertions, 94 deletions
diff --git a/uvim/runtime/tools/README.txt b/uvim/runtime/tools/README.txt
index 1758ca6533..bd45f37d45 100644
--- a/uvim/runtime/tools/README.txt
+++ b/uvim/runtime/tools/README.txt
@@ -1,4 +1,4 @@
-Some tools that can be used with Vim:
+Some tools that can be used with MNV:
blink.c: C program to make the cursor blink in an xterm.
@@ -8,7 +8,7 @@ ccfilter*: C program to filter the output of a few compilers to a common
efm_filter.*: Perl script to filter compiler messages to QuickFix format.
efm_perl.pl: Perl script to filter error messages from the Perl interpreter
- for use with Vim quickfix mode.
+ for use with MNV quickfix mode.
mve.* Awk script to filter error messages to QuickFix format.
@@ -16,25 +16,25 @@ pltags.pl: Perl script to create a tags file from Perl scripts.
ref: Shell script for the K command.
-preproc_indent.vim:
- Fix preprocessor indentation in Vim's C source code.
+preproc_indent.mnv:
+ Fix preprocessor indentation in MNV's C source code.
shtags.*: Perl script to create a tags file from a shell script.
-vim132: Shell script to edit in 132 column mode on vt100 compatible
+mnv132: Shell script to edit in 132 column mode on vt100 compatible
terminals.
-vimm: Shell script to start Vim on a DEC terminal with mouse
+mnvm: Shell script to start MNV on a DEC terminal with mouse
enabled.
-vimspell.*: Shell script for highlighting spelling mistakes.
+mnvspell.*: Shell script for highlighting spelling mistakes.
-vim_vs_net.cmd: MS-Windows command file to use Vim with MS Visual Studio 7 and
+mnv_vs_net.cmd: MS-Windows command file to use MNV with MS Visual Studio 7 and
later.
-xcmdsrv_client.c: Example for a client program that communicates with a Vim
+xcmdsrv_client.c: Example for a client program that communicates with a MNV
server through the X-Windows interface.
-unicode.vim Vim script to generate tables for src/mbyte.c.
+unicode.mnv MNV script to generate tables for src/mbyte.c.
[xxd can be found in the src directory]
diff --git a/uvim/runtime/tools/ccfilter.1 b/uvim/runtime/tools/ccfilter.1
index 92fe624dc8..8717960f34 100644
--- a/uvim/runtime/tools/ccfilter.1
+++ b/uvim/runtime/tools/ccfilter.1
@@ -1,6 +1,6 @@
.TH ccfilter 1 "01-Apr-97"
.SH NAME
-ccfilter \- a compiler's output filter for vim quickfix
+ccfilter \- a compiler's output filter for mnv quickfix
.SH SYNOPSIS
ccfilter [
.B <options>
@@ -8,8 +8,8 @@ ccfilter [
.SH DESCRIPTION
The ccfilter utility "filters" the output of several compilers
and makers (make/gmake) from several platforms (see NOTES below)
-to a standardized format which easily fits in vim's quickfix
-feature. For further details, see in vim ":help quickfix".
+to a standardized format which easily fits in mnv's quickfix
+feature. For further details, see in mnv ":help quickfix".
.PP
ccfilter reads
.B 'stdin'
@@ -24,12 +24,12 @@ display them !
When working on different platforms, and with different compilers,
ccfilter eases the utilization of quickfix, due to its standardized
-output, allowing to have in .vimrc a plain
+output, allowing to have in .mnvrc a plain
.br
.B \ \ \ \ :set\ errorformat=%f:%l:%c:%t:%m
.SH USAGE
-When using ccfilter, one would include the following lines in .vimrc:
+When using ccfilter, one would include the following lines in .mnvrc:
.br
.B \ \ \ \ :set shellpipe=\\\\|&ccfilter\\\\>
.br
diff --git a/uvim/runtime/tools/ccfilter.c b/uvim/runtime/tools/ccfilter.c
index ae1443e203..f9ae3b97a2 100644
--- a/uvim/runtime/tools/ccfilter.c
+++ b/uvim/runtime/tools/ccfilter.c
@@ -1,5 +1,5 @@
/* ======================================================================= */
-/* Project : VIM */
+/* Project : MNV */
/* Module : ccfilter Version: 02.01.01 */
/* File : ccfilter.c */
/* Purpose : Filter gmake/cc output into a standardized form */
@@ -71,7 +71,7 @@ char *COMPILER_Names[][2] =
const char USAGE[] =
"ccfilter v2.1 (c)1994-1997 by Pablo Ariel Kohan\n"
-"Filter Out compiler's output, and converts it to fit VIM\n\n"
+"Filter Out compiler's output, and converts it to fit MNV\n\n"
"Usage:\n"
" ccfilter [<options>]\n"
"Where: <options> is one or more of:\n"
diff --git a/uvim/runtime/tools/ccfilter_README.txt b/uvim/runtime/tools/ccfilter_README.txt
index ea989f2574..a8a4c16110 100644
--- a/uvim/runtime/tools/ccfilter_README.txt
+++ b/uvim/runtime/tools/ccfilter_README.txt
@@ -2,7 +2,7 @@ READ THIS FIRST
===============
ccfilter is a C program to filter the output of a few compilers to a common
-QuickFix format. It is provided with Vim to make quickfix useful for more
+QuickFix format. It is provided with MNV to make quickfix useful for more
compilers.
ccfilter WILL FAIL with long lines (more than 2047 bytes).
diff --git a/uvim/runtime/tools/demoserver.py b/uvim/runtime/tools/demoserver.py
index 2667aed396..f9f471a1f7 100644
--- a/uvim/runtime/tools/demoserver.py
+++ b/uvim/runtime/tools/demoserver.py
@@ -1,19 +1,19 @@
#!/usr/bin/python
#
-# Server that will accept connections from a Vim channel.
-# Run this server and then in Vim you can open the channel:
+# Server that will accept connections from a MNV channel.
+# Run this server and then in MNV you can open the channel:
# :let handle = ch_open('localhost:8765')
#
-# Then Vim can send requests to the server:
+# Then MNV can send requests to the server:
# :let response = ch_sendexpr(handle, 'hello!')
#
-# And you can control Vim by typing a JSON message here, e.g.:
+# And you can control MNV by typing a JSON message here, e.g.:
# ["ex","echo 'hi there'"]
#
# There is no prompt, just type a line and press Enter.
# To exit cleanly type "quit<Enter>".
#
-# See ":help channel-demo" in Vim.
+# See ":help channel-demo" in MNV.
#
# This requires Python 2.6 or later.
diff --git a/uvim/runtime/tools/efm_filter.pl b/uvim/runtime/tools/efm_filter.pl
index 1d1a4f303b..8631a9811d 100755
--- a/uvim/runtime/tools/efm_filter.pl
+++ b/uvim/runtime/tools/efm_filter.pl
@@ -1,7 +1,7 @@
#!/usr/bin/env perl
#
# This program works as a filter that reads from stdin, copies to
-# stdout *and* creates an error file that can be read by vim.
+# stdout *and* creates an error file that can be read by mnv.
#
# This program has only been tested on SGI, Irix5.3.
#
@@ -12,7 +12,7 @@
$args = @ARGV;
unless ($args == 1) {
- die("Usage: vimccparse <output filename>\n");
+ die("Usage: mnvccparse <output filename>\n");
}
$filename = @ARGV[0];
diff --git a/uvim/runtime/tools/efm_filter.txt b/uvim/runtime/tools/efm_filter.txt
index d3f97f45ad..2fd7cc8446 100644
--- a/uvim/runtime/tools/efm_filter.txt
+++ b/uvim/runtime/tools/efm_filter.txt
@@ -1,8 +1,8 @@
-[adopted from a message that Ives posted in the Vim mailing list]
+[adopted from a message that Ives posted in the MNV mailing list]
Some compilers produce an error message that cannot be handled with
-'errorformat' in Vim. Following is an example of a Perl script that
-translates one error message into something that Vim understands.
+'errorformat' in MNV. Following is an example of a Perl script that
+translates one error message into something that MNV understands.
The compiler that generates this kind of error messages (4 lines):
@@ -17,7 +17,7 @@ The way I use it is:
:set errorformat=%f>%l:%c:%t:%n:%m
:set makeprg=clearmake\ -C\ gnu
-:set shellpipe=2>&1\|\ vimccparse
+:set shellpipe=2>&1\|\ mnvccparse
If somebody thinks this is useful: feel free to do whatever you can think
of with this code.
diff --git a/uvim/runtime/tools/emoji_list.vim b/uvim/runtime/tools/emoji_list.mnv
index d361b7ee98..25939fba4b 100644
--- a/uvim/runtime/tools/emoji_list.vim
+++ b/uvim/runtime/tools/emoji_list.mnv
@@ -7,7 +7,7 @@ else
enew
endif
-" Use a compiled Vim9 function for speed
+" Use a compiled MNV9 function for speed
def DoIt()
var lnum = 1
for c in range(0x100, 0x1ffff)
diff --git a/uvim/runtime/tools/vim132 b/uvim/runtime/tools/mnv132
index 29ea4ce1ff..14582f54f0 100755
--- a/uvim/runtime/tools/vim132
+++ b/uvim/runtime/tools/mnv132
@@ -1,13 +1,13 @@
#!/bin/csh
#
# Shell script for use with UNIX
-# Starts up Vim with the terminal in 132 column mode
+# Starts up MNV with the terminal in 132 column mode
# Only works on VT-100 terminals and lookalikes
# You need to have a termcap entry "vt100-w". Same as vt100 but 132 columns.
#
set oldterm=$term
echo "[?3h"
setenv TERM vt100-w
-vim $*
+mnv $*
set term=$oldterm
echo "[?3l"
diff --git a/uvim/runtime/tools/vim_vs_net.cmd b/uvim/runtime/tools/mnv_vs_net.cmd
index 335236c920..c971555950 100644
--- a/uvim/runtime/tools/vim_vs_net.cmd
+++ b/uvim/runtime/tools/mnv_vs_net.cmd
@@ -2,8 +2,8 @@
@rem To use this with Visual Studio .Net
@rem Tools->External Tools...
@rem Add
-@rem Title - Vim
-@rem Command - d:\files\util\vim_vs_net.cmd
+@rem Title - MNV
+@rem Command - d:\files\util\mnv_vs_net.cmd
@rem Arguments - +$(CurLine) $(ItemPath)
@rem Init Dir - Empty
@rem
@@ -11,13 +11,13 @@
@rem
@rem --remote-silent +%1 is a command +954, move ahead 954 lines
@rem --remote-silent %2 full path to file
-@rem In Vim
+@rem In MNV
@rem :h --remote-silent for more details
@rem
@rem --servername VS_NET
-@rem This will create a new instance of vim called VS_NET. So if you open
-@rem multiple files from VS, they will use the same instance of Vim.
-@rem This allows you to have multiple copies of Vim running, but you can
+@rem This will create a new instance of mnv called VS_NET. So if you open
+@rem multiple files from VS, they will use the same instance of MNV.
+@rem This allows you to have multiple copies of MNV running, but you can
@rem control which one has VS files in it.
@rem
-start /b gvim.exe --servername VS_NET --remote-silent "%1" "%2"
+start /b gmnv.exe --servername VS_NET --remote-silent "%1" "%2"
diff --git a/uvim/runtime/tools/vimm b/uvim/runtime/tools/mnvm
index 7b84cb255e..5a9b0804c3 100755
--- a/uvim/runtime/tools/vimm
+++ b/uvim/runtime/tools/mnvm
@@ -1,6 +1,6 @@
#!/bin/sh
# enable DEC locator input model on remote terminal
printf "\033[1;2'z\033[1;3'{\c"
-vim "$@"
+mnv "$@"
# disable DEC locator input model on remote terminal
printf "\033[2;4'{\033[0'z\c"
diff --git a/uvim/runtime/tools/vimspell.txt b/uvim/runtime/tools/mnvspell.txt
index 2842af7bd8..2b90a2ec96 100644
--- a/uvim/runtime/tools/vimspell.txt
+++ b/uvim/runtime/tools/mnvspell.txt
@@ -1,15 +1,15 @@
-vimspell.sh
+mnvspell.sh
===========
This is a simple script to spell check a file and generate the syntax
-statements necessary to highlight the errors in vim. It is based on a
+statements necessary to highlight the errors in mnv. It is based on a
similar program by Krishna Gadepalli <krishna@stdavids.picker.com>.
To use this script, first place it in a directory in your path. Next,
you should add some convenient key mappings. I use the following (in
-.vimrc):
+.mnvrc):
- noremap <F8> :so `vimspell.sh %`<CR><CR>
+ noremap <F8> :so `mnvspell.sh %`<CR><CR>
noremap <F7> :syntax clear SpellErrors<CR>
This program requires the old Unix "spell" command. On my Debian
diff --git a/uvim/runtime/tools/mve.awk b/uvim/runtime/tools/mve.awk
index 396f80677c..c0f486154f 100755
--- a/uvim/runtime/tools/mve.awk
+++ b/uvim/runtime/tools/mve.awk
@@ -2,8 +2,8 @@
#
# Change "nawk" to "awk" or "gawk" if you get errors.
#
-# Make Vim Errors
-# Processes errors from cc for use by Vim's quick fix tools
+# Make MNV Errors
+# Processes errors from cc for use by MNV's quick fix tools
# specifically it translates the ---------^ notation to a
# column number
#
diff --git a/uvim/runtime/tools/mve.txt b/uvim/runtime/tools/mve.txt
index 8aa5cf66bf..9dc06455f2 100644
--- a/uvim/runtime/tools/mve.txt
+++ b/uvim/runtime/tools/mve.txt
@@ -1,10 +1,10 @@
-[ The mve awk script was posted on the vimdev mailing list ]
+[ The mve awk script was posted on the mnvdev mailing list ]
From: jimmer@barney.mdhc.mdc.com (J. McGlasson)
Date: Mon, 31 Mar 1997 13:16:49 -0700 (Mar)
My compiler (SGI MIPSpro C compiler - IRIX 6.4) works like this.
-I have written a script mve (make vim errors), through which I pipe my make
+I have written a script mve (make mnv errors), through which I pipe my make
output, which translates output of the following form:
cfe: Error: syntax.c, line 4: Syntax Error
@@ -15,6 +15,6 @@ into:
cl.c, line 4, col 12 : Syntax Error
-(in vim notation: %f, line %l, col %c : %m)
+(in mnv notation: %f, line %l, col %c : %m)
You might be able to tailor this for your compiler's output.
diff --git a/uvim/runtime/tools/preproc_indent.vim b/uvim/runtime/tools/preproc_indent.mnv
index 035ca0e247..6c257530fa 100644
--- a/uvim/runtime/tools/preproc_indent.vim
+++ b/uvim/runtime/tools/preproc_indent.mnv
@@ -1,7 +1,7 @@
-vim9script
-# Script to fix preprocessor indentation in Vim's C source code.
+mnv9script
+# Script to fix preprocessor indentation in MNV's C source code.
#
-# Usage: Vim -S <this-file>
+# Usage: MNV -S <this-file>
#
# Specifications:
# - If there is no indentation on the line containing the preprocessor
@@ -145,4 +145,4 @@ for fname in Get_C_source_files()
endfor
qall!
-# vim: et ts=2 sw=0
+# mnv: et ts=2 sw=0
diff --git a/uvim/runtime/tools/ref b/uvim/runtime/tools/ref
index 77bfc805e2..7da6b069f3 100755
--- a/uvim/runtime/tools/ref
+++ b/uvim/runtime/tools/ref
@@ -4,7 +4,7 @@
#
# Usage: ref word ..
#
-# can be used for the K command of Vim
+# can be used for the K command of MNV
#
spell <<EOF
$*
diff --git a/uvim/runtime/tools/unicode.vim b/uvim/runtime/tools/unicode.mnv
index 4086b188f3..6a5f2f3896 100644
--- a/uvim/runtime/tools/unicode.vim
+++ b/uvim/runtime/tools/unicode.mnv
@@ -4,7 +4,7 @@
" For the other files see the header.
"
" Might need to update the URL to the emoji-data.txt
-" Usage: Vim -S <this-file>
+" Usage: MNV -S <this-file>
"
" Author: Bram Moolenaar
" Last Update: 2025 Sep 21
diff --git a/uvim/runtime/tools/efm_perl.pl b/uvim/runtime/tools/efm_perl.pl
index 1aab2d4ea0..38f686e38e 100755
--- a/uvim/runtime/tools/efm_perl.pl
+++ b/uvim/runtime/tools/efm_perl.pl
@@ -1,40 +1,40 @@
#!/usr/bin/perl -w
# vimparse.pl - Reformats the error messages of the Perl interpreter for use
# with the quickfix mode of Vim
#
# Copyright (c) 2001 by Joerg Ziefle <joerg.ziefle@gmx.de>
# You may use and distribute this software under the same terms as Perl itself.
#
-# Usage: put one of the two configurations below in your ~/.vimrc (without the
-# description and '# ') and enjoy (be sure to adjust the paths to vimparse.pl
+# Usage: put one of the two configurations below in your ~/.mnvrc (without the
+# description and '# ') and enjoy (be sure to adjust the paths to mnvparse.pl
# before):
#
# Program is run interactively with 'perl -w':
#
-# set makeprg=$HOME/bin/vimparse.pl\ %\ $*
+# set makeprg=$HOME/bin/mnvparse.pl\ %\ $*
# set errorformat=%f:%l:%m
#
# Program is only compiled with 'perl -wc':
#
-# set makeprg=$HOME/bin/vimparse.pl\ -c\ %\ $*
+# set makeprg=$HOME/bin/mnvparse.pl\ -c\ %\ $*
# set errorformat=%f:%l:%m
#
# Usage:
-# vimparse.pl [-c] [-f <errorfile>] <programfile> [programargs]
+# mnvparse.pl [-c] [-f <errorfile>] <programfile> [programargs]
#
# -c compile only, don't run (perl -wc)
# -f write errors to <errorfile>
#
# Example usages:
# * From the command line:
-# vimparse.pl program.pl
+# mnvparse.pl program.pl
#
# vimparse.pl -c -f errorfile program.pl
# Then run vim -q errorfile to edit the errors with Vim.
#
# * From Vim:
# Edit in Vim (and save, if you don't have autowrite on), then
# type ':mak' or ':mak args' (args being the program arguments)
# to error check.
#
@@ -140,10 +140,10 @@ Examples:
Displays output on STDOUT.
$0 -c -f errorfile program.pl
- Then run 'vim -q errorfile' to edit the errors with Vim.
+ Then run 'mnv -q errorfile' to edit the errors with MNV.
- * In Vim:
- Edit in Vim (and save, if you don't have autowrite on), then
+ * In MNV:
+ Edit in MNV (and save, if you don't have autowrite on), then
type ':mak' or ':mak args' (args being the program arguments)
to error check.
EOT
@@ -1,40 +1,40 @@
#!/usr/bin/perl -w
-# vimparse.pl - Reformats the error messages of the Perl interpreter for use
-# with the quickfix mode of Vim
+# mnvparse.pl - Reformats the error messages of the Perl interpreter for use
+# with the quickfix mode of MNV
#
# Copyright (c) 2001 by Joerg Ziefle <joerg.ziefle@gmx.de>
@@ -1,40 +1,40 @@
#
-# vimparse.pl -c -f errorfile program.pl
-# Then run vim -q errorfile to edit the errors with Vim.
+# mnvparse.pl -c -f errorfile program.pl
+# Then run mnv -q errorfile to edit the errors with MNV.
#
@@ -1,40 +1,40 @@
#
-# * From Vim:
-# Edit in Vim (and save, if you don't have autowrite on), then
+# * From MNV:
+# Edit in MNV (and save, if you don't have autowrite on), then
# type ':mak' or ':mak args' (args being the program arguments)
# to error check.
diff --git a/uvim/runtime/tools/vimspell.sh b/uvim/runtime/tools/mnvspell.sh
index d336fe6c31..100306b4cd 100755
--- a/uvim/runtime/tools/vimspell.sh
+++ b/uvim/runtime/tools/mnvspell.sh
@@ -1,33 +1,33 @@
#!/bin/sh
#
# Spell a file & generate the syntax statements necessary to
-# highlight in vim. Based on a program from Krishna Gadepalli
+# highlight in mnv. Based on a program from Krishna Gadepalli
# <krishna@stdavids.picker.com>.
#
-# I use the following mappings (in .vimrc):
+# I use the following mappings (in .mnvrc):
#
-# noremap <F8> :so `vimspell.sh %`<CR><CR>
+# noremap <F8> :so `mnvspell.sh %`<CR><CR>
# noremap <F7> :syntax clear SpellErrors<CR>
#
# Neil Schemenauer <nascheme@ucalgary.ca>
# March 1999
# updated 2008 Jul 17 by Bram
#
-# Safe method for the temp file by Javier Fernández-Sanguino_Peña
+# Safe method for the temp file by Javier Fern�ndez-Sanguino_Pe�a
INFILE=$1
tmp="${TMPDIR-/tmp}"
-OUTFILE=`mktemp -t vimspellXXXXXX || tempfile -p vimspell || echo none`
+OUTFILE=`mktemp -t mnvspellXXXXXX || tempfile -p mnvspell || echo none`
# If the standard commands failed then create the file
# since we cannot create a directory (we cannot remove it on exit)
# create a file in the safest way possible.
if test "$OUTFILE" = none; then
- OUTFILE=$tmp/vimspell$$
+ OUTFILE=$tmp/mnvspell$$
[ -e $OUTFILE ] && { echo "Cannot use temporary file $OUTFILE, it already exists!"; exit 1 ; }
(umask 077; touch $OUTFILE)
fi
# Note the copy of vimspell cannot be deleted on exit since it is
# used by vim, otherwise it should do this:
# trap "rm -f $OUTFILE" 0 1 2 3 9 11 13 15
@@ -1,33 +1,33 @@
(umask 077; touch $OUTFILE)
fi
-# Note the copy of vimspell cannot be deleted on exit since it is
-# used by vim, otherwise it should do this:
+# Note the copy of mnvspell cannot be deleted on exit since it is
+# used by mnv, otherwise it should do this:
# trap "rm -f $OUTFILE" 0 1 2 3 9 11 13 15
diff --git a/uvim/runtime/tools/pltags.pl b/uvim/runtime/tools/pltags.pl
index 7a74682b87..fb76fab972 100755
--- a/uvim/runtime/tools/pltags.pl
+++ b/uvim/runtime/tools/pltags.pl
@@ -2,7 +2,7 @@
# pltags - create a tags file for Perl code, for use by vi(m)
#
-# Distributed with Vim <http://www.vim.org/>, latest version always available
+# Distributed with MNV <http://www.mnv.org/>, latest version always available
# at <http://www.mscha.com/mscha.html?pltags#tools>
#
# Version 2.3, 28 February 2002
@@ -168,7 +168,7 @@ unless ($status && @ARGV)
print " --vars (--novars) (don't) include variable declarations in tag file\n";
print " --pkgs (--nopkgs) (don't) include package declarations in tag file\n";
print " --extensions (--noextensions)\n";
- print " (don't) include Exuberant Ctags / Vim style\n";
+ print " (don't) include Exuberant Ctags / MNV style\n";
print " extensions in tag file\n\n";
print " Default options: ";
print ($do_subs ? "--subs " : "--nosubs ");
@@ -222,7 +222,7 @@ foreach $file (map { glob } @ARGV)
# Make a tag for this variable unless we're told not to. We
# assume that a variable is always static, unless it appears
# in a package before any sub. (Not necessarily true, but
# it's ok for most purposes and Vim works fine even if it is
# incorrect)
if ($do_vars)
{
@@ -259,7 +259,7 @@ foreach $file (map { glob } @ARGV)
# Make a tag for this sub unless we're told not to. We assume
# that a sub is static, unless it appears in a package. (Not
# necessarily true, but it's ok for most purposes and Vim works
# fine even if it is incorrect)
if ($do_subs)
{
@@ -222,7 +222,7 @@ foreach $file (map { glob } @ARGV)
# assume that a variable is always static, unless it appears
# in a package before any sub. (Not necessarily true, but
- # it's ok for most purposes and Vim works fine even if it is
+ # it's ok for most purposes and MNV works fine even if it is
# incorrect)
if ($do_vars)
@@ -259,7 +259,7 @@ foreach $file (map { glob } @ARGV)
# Make a tag for this sub unless we're told not to. We assume
# that a sub is static, unless it appears in a package. (Not
- # necessarily true, but it's ok for most purposes and Vim works
+ # necessarily true, but it's ok for most purposes and MNV works
# fine even if it is incorrect)
if ($do_subs)
diff --git a/uvim/runtime/tools/xcmdsrv_client.c b/uvim/runtime/tools/xcmdsrv_client.c
index 81ca66ceb9..32a97d1431 100644
--- a/uvim/runtime/tools/xcmdsrv_client.c
+++ b/uvim/runtime/tools/xcmdsrv_client.c
@@ -1,14 +1,14 @@
/* vi:set ts=8 sts=4 sw=4:
*
* VIM - Vi IMproved by Bram Moolenaar
* X-Windows communication by Flemming Madsen
*
* Do ":help uganda" in Vim to read copying and usage conditions.
* Do ":help credits" in Vim to see a list of people who contributed.
* See README.txt for an overview of the Vim source code.
*
* Client for sending commands to an '+xcmdsrv' enabled vim.
* This is mostly a de-Vimified version of if_xcmdsrv.c in vim.
* See that file for a protocol specification.
*
* You can make a test program with a Makefile like:
@@ -30,7 +30,7 @@
#include <X11/Xatom.h>
/* Client API */
-char * sendToVim(Display *dpy, char *name, char *cmd, int asKeys, int *code);
+char * sendToMNV(Display *dpy, char *name, char *cmd, int asKeys, int *code);
#ifdef MAIN
/* A sample program */
@@ -41,7 +41,7 @@ main(int argc, char **argv)
if (argc == 4)
{
- if ((res = sendToVim(XOpenDisplay(NULL), argv[2], argv[3],
+ if ((res = sendToMNV(XOpenDisplay(NULL), argv[2], argv[3],
argv[1][0] != 'e', &code)) != NULL)
{
if (code)
@@ -86,15 +86,15 @@ static int got_x_error = FALSE;
/*
* sendToVim --
* Send to an instance of Vim via the X display.
*
* Results:
* A string with the result or NULL. Caller must free if non-NULL
*/
char *
-sendToVim(
+sendToMNV(
Display *dpy, /* Where to send. */
char *name, /* Where to send. */
char *cmd, /* What to send. */
@@ -258,7 +258,7 @@ SendInit(Display *dpy)
commProperty = XInternAtom(dpy, "Comm", False);
/* Change this back to "InterpRegistry" to talk to tk processes */
- registryProperty = XInternAtom(dpy, "VimRegistry", False);
+ registryProperty = XInternAtom(dpy, "MNVRegistry", False);
if (commWindow == None)
{
@@ -1,14 +1,14 @@
/* vi:set ts=8 sts=4 sw=4:
*
- * VIM - Vi IMproved by Bram Moolenaar
+ * MNV - MNV is not Vim by Bram Moolenaar
* X-Windows communication by Flemming Madsen
*
@@ -1,14 +1,14 @@
* X-Windows communication by Flemming Madsen
*
- * Do ":help uganda" in Vim to read copying and usage conditions.
- * Do ":help credits" in Vim to see a list of people who contributed.
- * See README.txt for an overview of the Vim source code.
+ * Do ":help uganda" in MNV to read copying and usage conditions.
+ * Do ":help credits" in MNV to see a list of people who contributed.
+ * See README.txt for an overview of the MNV source code.
*
@@ -1,14 +1,14 @@
*
- * Client for sending commands to an '+xcmdsrv' enabled vim.
- * This is mostly a de-Vimified version of if_xcmdsrv.c in vim.
+ * Client for sending commands to an '+xcmdsrv' enabled mnv.
+ * This is mostly a de-MNVified version of if_xcmdsrv.c in mnv.
* See that file for a protocol specification.
*
@@ -86,15 +86,15 @@ static int got_x_error = FALSE;
/*
- * sendToVim --
- * Send to an instance of Vim via the X display.
+ * sendToMNV --
+ * Send to an instance of MNV via the X display.
*
* Results: